from .wh_Path import Path
from .wh_ReadIni import ReadIni
from .wh_Time import Time
from .wh_WebService import WebService
from .wh_DBUtil import DBUtil


__all__ = ['Path', 'ReadIni', 'Time', 'WebService', 'DBUtil']


import datetime
from dateutil.relativedelta import relativedelta


class Time(object):

    # 获取当前日期时间，返回datetime类型，格式为 %Y-%m-%d %H:%M:%S
    def getNowDatetime(self):
        now = datetime.datetime.now()
        now_str = datetime.datetime.strftime(now,"%Y-%m-%d %H:%M:%S")
        return datetime.datetime.strptime(now_str, "%Y-%m-%d %H:%M:%S")

    # 获取当前日期，返回date类型，格式为 %Y-%m-%d
    def getNowDate(self):
        now = datetime.date.today()
        return now

    # 获取前一秒钟日期时间
    def getLastSecond(self, time):
        return time - datetime.timedelta(seconds=1)

    # 返回指定日期时间+n秒钟
    def addSecond(self, time, n):
        return time + datetime.timedelta(seconds=n)

    # 获取前一分钟日期时间
    def getLastMinute(self, time):
        return time - datetime.timedelta(minutes=1)

    # 返回指定日期时间+n分钟
    def addMinute(self, time, n):
        return time + datetime.timedelta(minutes=n)

    # 获取前一小时日期时间
    def getLastHour(self, time):
        return time - datetime.timedelta(hours=1)

    # 返回指定日期时间+n小时
    def addHour(self, time, n):
        return time + datetime.timedelta(hours=n)

    # 获取前一天日期时间
    def getLastDay(self, time):
        return time - datetime.timedelta(days=1)

    # 返回指定日期时间+n天
    def addDay(self, time, n):
        return time + datetime.timedelta(days=n)

    # 获取前一周日期时间
    def getLastWeek(self, time):
        return time - datetime.timedelta(weeks=1)

    # 返回指定日期时间+n周
    def addWeek(self, time, n):
        return time + datetime.timedelta(weeks=n)

    # 获取前一月日期时间
    def getLastMonth(self, time):
        return time - relativedelta(months=1)

    # 返回指定日期时间+n月
    def addMonth(self, time, n):
        return time + relativedelta(months=n)

    # 获取前一年日期时间
    def getLastYear(self, time):
        return time - relativedelta(years=1)

    # 返回指定日期时间+n年
    def addYear(self, time, n):
        return time + relativedelta(years=n)

    # 获取两个时间的时间差，返回timedelta，前-后
    def getDulartion(self, time1, time2):
        return time1 - time2

    # 获取两个时间的时间差的字符串描述：*年*天*小时*分*秒，若相等，返回'0'
    def getDulartionStr(self, time1, time2):
        second_str = ''
        minute_str = ''
        hour_str = ''
        day_str = ''
        year_str = ''
        dulartion = time1 - time2
        total = int(dulartion.total_seconds())
        second = total % 60
        if second != 0:
            second_str = str(second) + '秒'
        total = int(total / 60)
        minute = total % 60
        if minute != 0:
            minute_str = str(minute) + '分'
        total = int(total / 60)
        hour = total % 24
        if hour != 0:
            hour_str = str(hour) + '小时'
        total = int(total / 24)
        day = total % 365
        if day != 0:
            day_str = str(day) + '天'
        year = int(total / 365)
        if year != 0:
            year_str = str(year) + '年'
        dulartion_str = year_str + day_str + hour_str + minute_str + second_str
        if dulartion_str == '':
            dulartion_str = '0'
        return dulartion_str


    # 获取两个时间的时间差（秒级），返回int
    def getDulartionSeconds(self, time1, time2):
        dulartion = time1 - time2
        return int(dulartion.total_seconds())

    # 获取两个时间的时间差（分钟级），返回int
    def getDulartionMinutes(self, time1, time2):
        dulartion = time1 - time2
        seconds = int(dulartion.total_seconds())
        return int(seconds/60)

    # 获取两个时间的时间差（小时级），返回int
    def getDulartionHours(self, time1, time2):
        dulartion = time1 - time2
        seconds = int(dulartion.total_seconds())
        return int(seconds/60/60)

    # 获取两个时间的时间差（天级），返回int
    def getDulartionDays(self, time1, time2):
        dulartion = time1 - time2
        seconds = int(dulartion.total_seconds())
        return int(seconds/60/60/24)

    # 比较两个时间大小，前>后，返回1，前<后，返回-1，前=后，返回0
    def compare(self, time1, time2):
        dulartion = time1 - time2
        seconds = int(dulartion.total_seconds())
        if seconds > 0:
            return 1
        elif seconds < 0:
            return -1
        else:
            return 0

    # datetime 转 str
    def datetimeToStr(self, time):
        return datetime.datetime.strftime(time, "%Y-%m-%d %H:%M:%S")

    # str 转 datetime
    def strToDatetime(self, time_str):
        return datetime.datetime.strptime(time_str, "%Y-%m-%d %H:%M:%S")

    # date 转 str
    def dateToStr(self, time):
        return datetime.datetime.strftime(time, "%Y-%m-%d")

    # str 转 date
    def strToDate(self, time_str):
        return datetime.datetime.strptime(time_str, "%Y-%m-%d")

    # datetime 转 date
    def datetimeToDate(self, time):
        return time.date()

    # date 转 datetime
    def dateToDatetime(self, time):
        time_str = datetime.datetime.strftime(time, "%Y-%m-%d") + " 00:00:00"
        return datetime.datetime.strptime(time_str, "%Y-%m-%d %H:%M:%S")



if __name__=='__main__':
    a = Time()
    b = a.getNowDate()
    print(b)
    print(type(b))
    c = a.dateToDatetime(b)
    print(c)
    print(type(c))


import requests
import json


class WebService(object):
    def __init__(self):
        self.se = requests.session()

    # GET方法
    def Get(self, url, params=None):
        res = self.se.get(url=url, params=params)
        res = res.json()
        return res

    # POST方法
    def Post(self, url, data=None, json=None):
        res = self.se.post(url=url, data=data, json=json)
        res = res.json()
        return res










if __name__=='__main__':
    a = WebService()
    data = {"filter":{"name":"","level":"","nowduty":"","seePeriod":["",""],"endPeriod":["",""]},"page":{"pageNumber":1,"pageSize":"10"},"ticket":"d2VuaGFvYw=="}
    res = a.Post(url='http://localhost:8000/alert/getAlertList', json=data)
    print(res)


import pymysql


class DBUtil(object):
    def __init__(self, host, db, user, password):
        self.host = host
        self.db = db
        self.user = user
        self.password = password
        self.connect = pymysql.connect(host=self.host, db=self.db, user=self.user, password=self.password, charset="gbk",cursorclass=pymysql.cursors.DictCursor)

    # 测试连接是够有效，无效则重连
    def testConnect(self):
        try:
            self.connect.ping()
        except:
            self.connect = pymysql.connect(host=self.host, db=self.db, user=self.user, password=self.password, charset="gbk",cursorclass=pymysql.cursors.DictCursor)

    # 执行查询sql，成功返回结果，失败返回False
    def Select(self, sql, params=None):
        try:
            self.testConnect()
            cursor = self.connect.cursor()
            cursor.execute(sql, params)
            res = cursor.fetchall()
            cursor.close()
            return res
        except Exception as e:
            return False

    # 执行插入sql，成功返回最后一行的主键，失败返回False
    def Insert(self, sql, param=None):
        try:
            self.testConnect()
            cursor = self.connect.cursor()
            cursor.execute(sql, param)
            self.connect.commit()
            lastRowId = int(cursor.lastrowid)
            return lastRowId
        except Exception as e:
            self.connect.rollback()
            return False

    # 执行删除sql，成功返回True，失败返回False
    def Delete(self, sql, param=None):
        try:
            self.testConnect()
            cursor = self.connect.cursor()
            cursor.execute(sql, param)
            self.connect.commit()
            return True
        except Exception as e:
            self.connect.rollback()
            return False

    # 执行更新sql，成功返回True，失败返回False
    def Update(self, sql, param=None):
        try:
            self.testConnect()
            cursor = self.connect.cursor()
            cursor.execute(sql, param)
            self.connect.commit()
            return True
        except Exception as e:
            self.connect.rollback()
            return False



if __name__=='__main__':
    a = DBUtil(host='localhost', db='esu', user='root', password='123456')
    sql = '''select * from alert_msg'''
    res = a.Select(sql)
    print(res)


from setuptools import setup, find_packages

setup(
    name = 'whTool',
    version = '0.0.2',
    keywords='wh',
    description = 'a library for wh Developer',
    license = 'MIT License',
    url = 'https://gitlab.enncloud.cn/wenhaoc/whTool.git',
    author = 'wenhaoc',
    author_email = 'wenhaoc@enn.cn',
    packages = find_packages(),
    include_package_data = True,
    platforms = 'any',
    install_requires = [
        'python-dateutil',
        'requests',
        'pymysql',
        ],
)


from os import path
from os import walk
import sys

'''
    封装路径方法类
'''

class Path(object):

    # 获取当前文件路径
    def getCurrentFilePath(self):
        return sys.argv[0]

    # 获取当前文件所在文件夹路径
    def getCurrentDirPath(self):
        return path.dirname(sys.argv[0])

    # 获取传入文件/文件夹所在的文件夹路径（上一级文件夹路径）
    def getDirPath(self, file_path):
        return path.dirname(file_path)

    # 查找指定文件夹下，指定文件的路径，未找到返回None
    def getFilePathByName(self, dir_path, file_name):
        for root, dirs, files in walk(dir_path):
            for file in files:
                if file == file_name:
                    return path.join(root, file)
            for dir in dirs:
                self.getFilePathByName(path.join(root, dir), file_name)
        return None

    # 查找指定文件夹下，指定文件夹的路径，未找到返回None
    def getDirPathByName(self, dir_path, dir_name):
        for root, dirs, files in walk(dir_path):
            for dir in dirs:
                if dir == dir_name:
                    return path.join(root, dir)
                else:
                    self.getDirPathByName(path.join(root, dir), dir_name)
        return None




if __name__=='__main__':
    a = Path()
    b = a.getCurrentDirPath()
    c = a.getDirPath(b)
    print(c)
    d = a.getDirPathByName(c, 'test_dir')
    print(d)
    print(a.getFilePathByName(d, 'conf.ini'))


import configparser


class ReadIni(object):
    def __init__(self, ini_file_path):
        self.cf = configparser.RawConfigParser()
        self.cf.read(ini_file_path, encoding='utf-8')

    # 获取ini文件下的所有section，list返回，若无返回[]
    def getSections(self):
        return self.cf.sections()

    # 获取ini文件下，指定section的所有options，list返回，若无返回[]，若section不存在，返回None
    def getOptionsBySection(self, section):
        if self.cf.has_section(section):
            return self.cf.options(section)
        else:
            return None

    # 获取ini文件下，指定section的指定option的值value，返回字符串，若section/option不存在，则返回None
    def getValue(self, section, option):
        if self.cf.has_option(section, option):
            return self.cf.get(section, option)
        else:
            return None

    # 获取ini文件下，指定section的所有items（options与values的键值对，元组形式），list返回[(option1, value1), (option2, value2)]，若无返回[]，若section不存在，返回None
    def getItemsBySection(self, section):
        if self.cf.has_section(section):
            return self.cf.items(section)
        else:
            return None